@@ -1,5 +1,4 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
@@ -15,8 +14,9 @@ public:
     FROM_JSON_OVERLOADS(Channel)
     static Channel fromJson(const QJsonObject &, Channel &);
 
+    QString id() const;
+
     QString name() const;
-    void setName(const QString &name);
 
     QString banner() const;
     void setBanner(const QString &banner);
@@ -25,12 +25,11 @@ public:
     void setAvatar(const QString &avatar);
 
     QString description() const;
-    void setDescription(const QString &description);
 
     int subCount() const;
-    void setSubCount(int count);
 
 private:
+    QString m_id;
     QString m_name;
     QString m_banner;
     QString m_avatar;
